function [ structure ] = add_spectrum_pair( format1, format2, structure )
%ADDSPECTRUMPAIR Summary of this function goes here
%   Detailed explanation goes here
    
    
    % Read spectrum header
    fileID = fopen(sprintf(format1, 1), 'r');
    raw_header = fread(fileID, 512, 'float32');
    fclose(fileID);
    header1 = get_header_data(raw_header);
    
    % Initialize data structure or verify that dimension sizes match previous spectra
    if nargin < 3
        structure = struct();
        structure.num_pairs = 0;
        structure.I = header1(26,1);
        structure.J = header1(26,3);
        structure.K = [];
        structure.L = [];
        structure.headers = {};
        structure.formats = {};
        structure.subsumed = [];
    else
        if header1(26,1) ~= structure.I || header1(26,3) ~= structure.J
            error('IJKL_covar:dimensionMismatch', 'Dimension mismatch in first spectrum');
        end
    end
    
    % Edit header
    if raw_header(25 + 1) == 3 % if FDDIMORDER2 == 3, swap columns except for size
        header1(1:25,2:3) = header1(1:25,[3 2]);
    end
    header1(26,3:4) = 1; % Set size row to reflect that we deal with single planes
    header1(27,:) = [1 -1 -1 -1]; % Set header row for axes subsumed in covariance
    
    % Add spectrum to data structure
    structure.num_pairs = structure.num_pairs + 1;
    np = structure.num_pairs;
    structure.headers{1,np} = header1;
    structure.formats{1,np} = format1;

    % Read spectrum header
    fileID = fopen(sprintf(format2, 1), 'r');
    raw_header = fread(fileID, 512, 'float32');
    fclose(fileID);
    header2 = get_header_data(raw_header);
    
    % Initialize data structure or verify that dimension sizes match previous spectra
    if nargin < 3
        structure.K = header2(26,1);
        structure.L = header2(26,3);
    else
        if header2(26,1) ~= structure.K || header2(26,3) ~= structure.L
            error('IJKL_covar:dimensionMismatch', 'Dimension mismatch in second spectrum');
        end
    end
    
    % Verify that the subsumed dimension length matches
    if header1(26,2) ~= header2(26,2)
        error('IJKL_covar:dimensionMismatch', 'Subsumed dimension mismatch in spectrum pair');
    end
    
    % Edit header
    if raw_header(25 + 1) == 3
        header2(1:25,2:3) = header2(1:25,[3 2]);
    end
    header2(26,3:4) = 1;
    header2(27,:) = [1 -1 -1 -1];
    
    % Add spectrum to data structure
    structure.headers{2,np} = header2;
    structure.formats{2,np} = format2;
    structure.subsumed(np) = header2(26,2);
    
    return;
end

